@@ -1,4 +1,3 @@
-use crate::serialize_vec_enum_option;
 use serde::{Deserialize, Serialize};
 
 /// Health
@@ -16,6 +15,7 @@ pub struct Health {
     /// * HealthKit
     #[serde(
         rename = "com.apple.developer.healthkit",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub healthkit: Option<bool>,
@@ -43,7 +43,7 @@ pub struct Health {
     #[serde(
         rename = "com.apple.developer.healthkit.access",
         skip_serializing_if = "Option::is_none",
-        serialize_with = "serialize_vec_enum_option"
+        serialize_with = "crate::serialize_vec_enum_option"
     )]
     pub healthkit_access: Option<Vec<HealthKitCapabilities>>,
 }
