@@ -11,7 +11,6 @@
 //! ## Framework
 //! * Bundle Resources
 
-use crate::{serialize_enum_option, serialize_vec_enum_option};
 use serde::{Deserialize, Serialize};
 
 /// Categorization
@@ -34,6 +33,7 @@ pub struct Categorization {
     /// Core Foundation
     #[serde(
         rename = "CFBundlePackageType",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub bundle_package_type: Option<String>,
@@ -47,7 +47,7 @@ pub struct Categorization {
     #[serde(
         rename = "LSApplicationCategoryType",
         skip_serializing_if = "Option::is_none",
-        serialize_with = "serialize_enum_option"
+        serialize_with = "crate::serialize_enum_option"
     )]
     pub application_category_type: Option<AppCategoryType>,
 }
@@ -84,6 +84,7 @@ pub struct Identification {
     /// * WatchKit
     #[serde(
         rename = "WKAppBundleIdentifier",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub app_bundle_identifier: Option<String>,
@@ -100,6 +101,7 @@ pub struct Identification {
     /// * WatchKit
     #[serde(
         rename = "WKCompanionAppBundleIdentifier",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub companion_app_bundle_identifier: Option<String>,
@@ -121,7 +123,11 @@ pub struct Naming {
     ///
     /// ## Framework
     /// Core Foundation
-    #[serde(rename = "CFBundleName")]
+    #[serde(
+        rename = "CFBundleName",
+        serialize_with = "crate::serialize_option",
+        skip_serializing_if = "Option::is_none"
+    )]
     pub bundle_name: Option<String>,
     /// The user-visible name for the bundle, used by Siri and visible on the iOS Home
     /// screen.
@@ -138,6 +144,7 @@ pub struct Naming {
     /// Core Foundation
     #[serde(
         rename = "CFBundleDisplayName",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub bundle_display_name: Option<String>,
@@ -186,7 +193,11 @@ pub struct BundleVersion {
     ///
     /// ## Framework
     /// Core Foundation
-    #[serde(rename = "CFBundleVersion", skip_serializing_if = "Option::is_none")]
+    #[serde(
+        rename = "CFBundleVersion",
+        serialize_with = "crate::serialize_option",
+        skip_serializing_if = "Option::is_none"
+    )]
     pub bundle_version: Option<String>,
     /// The release or version number of the bundle.
     ///
@@ -212,6 +223,7 @@ pub struct BundleVersion {
     /// Core Foundation
     #[serde(
         rename = "CFBundleShortVersionString",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub bundle_short_version_string: Option<String>,
@@ -229,6 +241,7 @@ pub struct BundleVersion {
     /// Core Foundation
     #[serde(
         rename = "CFBundleInfoDictionaryVersion",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub bundle_info_dictionary_version: Option<String>,
@@ -241,6 +254,7 @@ pub struct BundleVersion {
     /// * Foundation
     #[serde(
         rename = "NSHumanReadableCopyright",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub human_readable_copyright: Option<String>,
@@ -261,6 +275,7 @@ pub struct OperatingSystemVersion {
     /// * Core Services
     #[serde(
         rename = "LSMinimumSystemVersion",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub minimum_system_version: Option<String>,
@@ -274,6 +289,7 @@ pub struct OperatingSystemVersion {
     /// * Core Services
     #[serde(
         rename = "LSMinimumSystemVersionByArchitecture",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub minimum_system_version_by_architecture: Option<MinimumSystemVersionByArchitecture>,
@@ -289,7 +305,11 @@ pub struct OperatingSystemVersion {
     ///
     /// ## Framework
     /// * Core Services
-    #[serde(rename = "MinimumOSVersion", skip_serializing_if = "Option::is_none")]
+    #[serde(
+        rename = "MinimumOSVersion",
+        serialize_with = "crate::serialize_option",
+        skip_serializing_if = "Option::is_none"
+    )]
     pub minimum_os_version: Option<String>,
     /// A Boolean value indicating whether the app must run in iOS.
     ///
@@ -298,7 +318,11 @@ pub struct OperatingSystemVersion {
     ///
     /// ## Framework
     /// * Core Services
-    #[serde(rename = "LSRequiresIPhoneOS", skip_serializing_if = "Option::is_none")]
+    #[serde(
+        rename = "LSRequiresIPhoneOS",
+        serialize_with = "crate::serialize_option",
+        skip_serializing_if = "Option::is_none"
+    )]
     pub requires_iphone_os: Option<bool>,
     /// A Boolean value that indicates whether the bundle is a watchOS app.
     ///
@@ -310,7 +334,11 @@ pub struct OperatingSystemVersion {
     ///
     /// ## Framework
     /// * WatchKit
-    #[serde(rename = "WKWatchKitApp", skip_serializing_if = "Option::is_none")]
+    #[serde(
+        rename = "WKWatchKitApp",
+        serialize_with = "crate::serialize_option",
+        skip_serializing_if = "Option::is_none"
+    )]
     pub watch_kit_app: Option<bool>,
 }
 
@@ -342,6 +370,7 @@ pub struct Localization {
     /// Core Foundation
     #[serde(
         rename = "CFBundleDevelopmentRegion",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub bundle_development_region: Option<String>,
@@ -358,7 +387,7 @@ pub struct Localization {
     #[serde(
         rename = "CFBundleLocalizations",
         skip_serializing_if = "Option::is_none",
-        serialize_with = "serialize_vec_enum_option"
+        serialize_with = "crate::serialize_vec_enum_option"
     )]
     pub bundle_localizations: Option<Vec<BundleLocalizations>>,
     /// A Boolean value that indicates whether the bundle supports the retrieval of
@@ -374,6 +403,7 @@ pub struct Localization {
     /// Core Foundation
     #[serde(
         rename = "CFBundleAllowMixedLocalizations",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub bundle_allow_mixed_localizations: Option<bool>,
@@ -396,6 +426,7 @@ pub struct Localization {
     /// * AppKit
     #[serde(
         rename = "TICapsLockLanguageSwitchCapable",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub caps_lock_language_switch_capable: Option<bool>,
@@ -411,7 +442,11 @@ pub struct Help {
     ///
     /// ## Framework
     /// * Core Foundation
-    #[serde(rename = "CFAppleHelpAnchor", skip_serializing_if = "Option::is_none")]
+    #[serde(
+        rename = "CFAppleHelpAnchor",
+        serialize_with = "crate::serialize_option",
+        skip_serializing_if = "Option::is_none"
+    )]
     pub apple_help_anchor: Option<String>,
     /// The name of the help file that will be opened in Help Viewer.
     ///
@@ -422,6 +457,7 @@ pub struct Help {
     /// * Core Foundation
     #[serde(
         rename = "CFBundleHelpBookName",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub bundle_help_book_name: Option<String>,
@@ -434,6 +470,7 @@ pub struct Help {
     /// * Core Foundation
     #[serde(
         rename = "CFBundleHelpBookFolder",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub bundle_help_book_folder: Option<String>,
