@@ -11,7 +11,6 @@
 //! The system displays this string when prompting the user, as described in Requesting
 //! Access to Protected Resources.
 
-use crate::serialize_vec_enum_option;
 use serde::{Deserialize, Serialize};
 
 /// Bluetooth
@@ -35,6 +34,7 @@ pub struct Bluetooth {
     /// * Core Bluetooth
     #[serde(
         rename = "NSBluetoothAlwaysUsageDescription",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub bluetooth_always_usage_description: Option<String>,
@@ -62,6 +62,7 @@ pub struct Bluetooth {
     #[deprecated(since = "iOS 6.0–13.0")]
     #[serde(
         rename = "NSBluetoothPeripheralUsageDescription",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub bluetooth_peripheral_usage_description: Option<String>,
@@ -86,6 +87,7 @@ pub struct CalendarAndReminders {
     /// * EventKit
     #[serde(
         rename = "NSCalendarsUsageDescription",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub calendars_usage_description: Option<String>,
@@ -103,6 +105,7 @@ pub struct CalendarAndReminders {
     /// * EventKit
     #[serde(
         rename = "NSRemindersUsageDescription",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub reminders_usage_description: Option<String>,
@@ -129,6 +132,7 @@ pub struct CameraAndMicrophone {
     /// * AVFoundation
     #[serde(
         rename = "NSCameraUsageDescription",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub camera_usage_description: Option<String>,
@@ -147,6 +151,7 @@ pub struct CameraAndMicrophone {
     /// * AVFoundation
     #[serde(
         rename = "NSMicrophoneUsageDescription",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub microphone_usage_description: Option<String>,
@@ -171,6 +176,7 @@ pub struct Contacts {
     /// * Contacts
     #[serde(
         rename = "NSContactsUsageDescription",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub contacts_usage_description: Option<String>,
@@ -192,6 +198,7 @@ pub struct FaceId {
     /// * Local Authentication
     #[serde(
         rename = "NSFaceIDUsageDescription",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub face_id_usage_description: Option<String>,
@@ -234,6 +241,7 @@ pub struct FilesAndFolders {
     /// * Foundation
     #[serde(
         rename = "NSDesktopFolderUsageDescription",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub desktop_folder_usage_description: Option<String>,
@@ -271,6 +279,7 @@ pub struct FilesAndFolders {
     /// * Foundation
     #[serde(
         rename = "NSDocumentsFolderUsageDescription",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub documents_folder_usage_description: Option<String>,
@@ -308,6 +317,7 @@ pub struct FilesAndFolders {
     /// * Foundation
     #[serde(
         rename = "NSDownloadsFolderUsageDescription",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub downloads_folder_usage_description: Option<String>,
@@ -342,6 +352,7 @@ pub struct FilesAndFolders {
     /// * Foundation
     #[serde(
         rename = "NSNetworkVolumesUsageDescription",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub network_volumes_usage_description: Option<String>,
@@ -375,6 +386,7 @@ pub struct FilesAndFolders {
     /// * Foundation
     #[serde(
         rename = "NSRemovableVolumesUsageDescription",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub removable_volumes_usage_description: Option<String>,
@@ -403,6 +415,7 @@ pub struct FilesAndFolders {
     /// * Foundation
     #[serde(
         rename = "NSFileProviderPresenceUsageDescription",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub file_provider_presence_usage_description: Option<String>,
@@ -436,6 +449,7 @@ pub struct FilesAndFolders {
     /// * Foundation
     #[serde(
         rename = "NSFileProviderDomainUsageDescription",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub file_provider_domain_usage_description: Option<String>,
@@ -476,6 +490,7 @@ pub struct Health {
     /// * HealthKit
     #[serde(
         rename = "com.apple.developer.healthkit",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub healthkit: Option<bool>,
@@ -503,7 +518,7 @@ pub struct Health {
     #[serde(
         rename = "com.apple.developer.healthkit.access",
         skip_serializing_if = "Option::is_none",
-        serialize_with = "serialize_vec_enum_option"
+        serialize_with = "crate::serialize_vec_enum_option"
     )]
     pub healthkit_access: Option<Vec<HealthKitCapabilities>>,
     /// A message to the user that explains why the app requested permission to read
@@ -520,6 +535,7 @@ pub struct Health {
     /// * HealthKit
     #[serde(
         rename = "NSHealthClinicalHealthRecordsShareUsageDescription",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub health_clinical_health_records_share_usage_description: Option<String>,
@@ -536,6 +552,7 @@ pub struct Health {
     /// * HealthKit
     #[serde(
         rename = "NSHealthShareUsageDescription",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub health_share_usage_description: Option<String>,
@@ -552,6 +569,7 @@ pub struct Health {
     /// * HealthKit
     #[serde(
         rename = "NSHealthUpdateUsageDescription",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub health_update_usage_description: Option<String>,
@@ -574,6 +592,7 @@ pub struct Health {
     /// * HealthKit
     #[serde(
         rename = "NSHealthRequiredReadAuthorizationTypeIdentifiers",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub health_required_read_authorization_type_identifiers: Option<Vec<String>>,
@@ -602,6 +621,7 @@ pub struct Home {
     /// * HomeKit
     #[serde(
         rename = "NSHomeKitUsageDescription",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub home_kit_usage_description: Option<String>,
@@ -635,6 +655,7 @@ pub struct Location {
     /// * Core Location
     #[serde(
         rename = "NSLocationAlwaysAndWhenInUseUsageDescription",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub location_always_and_when_in_use_usage_description: Option<String>,
@@ -658,6 +679,7 @@ pub struct Location {
     #[deprecated(since = "iOS 6.0–8.0")]
     #[serde(
         rename = "NSLocationUsageDescription",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub location_usage_description: Option<String>,
@@ -683,6 +705,7 @@ pub struct Location {
     /// * Core Location
     #[serde(
         rename = "NSLocationWhenInUseUsageDescription",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub location_when_in_use_usage_description: Option<String>,
@@ -712,6 +735,7 @@ pub struct Location {
     /// * Core Location
     #[serde(
         rename = "NSLocationTemporaryUsageDescriptionDictionary",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub location_temporary_usage_description_dictionary: Option<DefaultDictionary>,
@@ -748,6 +772,7 @@ pub struct Location {
     )]
     #[serde(
         rename = "NSLocationAlwaysUsageDescription",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub location_always_usage_description: Option<String>,
@@ -769,6 +794,7 @@ pub struct Location {
     /// * WidgetKit
     #[serde(
         rename = "NSWidgetWantsLocation",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub widget_wants_location: Option<bool>,
@@ -815,6 +841,7 @@ pub struct Location {
     /// * Core Location
     #[serde(
         rename = "NSLocationDefaultAccuracyReduced",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub location_default_accuracy_reduced: Option<bool>,
@@ -850,6 +877,7 @@ pub struct MediaPlayer {
     /// * Media Player
     #[serde(
         rename = "NSAppleMusicUsageDescription",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub apple_music_usage_description: Option<String>,
@@ -875,6 +903,7 @@ pub struct Motion {
     /// * Core Motion
     #[serde(
         rename = "NSMotionUsageDescription",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub motion_usage_description: Option<String>,
@@ -891,6 +920,7 @@ pub struct Motion {
     /// * Core Motion
     #[serde(
         rename = "NSFallDetectionUsageDescription",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub fall_detection_usage_description: Option<String>,
@@ -915,6 +945,7 @@ pub struct Networking {
     /// * Network
     #[serde(
         rename = "NSLocalNetworkUsageDescription",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub local_network_usage_description: Option<String>,
@@ -936,6 +967,7 @@ pub struct Networking {
     /// * Nearby Interaction
     #[serde(
         rename = "NSNearbyInteractionAllowOnceUsageDescription",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub nearby_interaction_allow_once_usage_description: Option<String>,
@@ -958,6 +990,7 @@ pub struct Nfc {
     /// * Core NFC
     #[serde(
         rename = "NFCReaderUsageDescription",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub nfc_reader_usage_description: Option<String>,
@@ -982,6 +1015,7 @@ pub struct Photos {
     /// * Photos
     #[serde(
         rename = "NSPhotoLibraryAddUsageDescription",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub photo_library_add_usage_description: Option<String>,
@@ -1003,6 +1037,7 @@ pub struct Photos {
     /// * Photos
     #[serde(
         rename = "NSPhotoLibraryUsageDescription",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub photo_library_usage_description: Option<String>,
@@ -1020,6 +1055,7 @@ pub struct Scripting {
     /// * Foundation
     #[serde(
         rename = "NSAppleScriptEnabled",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub apple_script_enabled: Option<bool>,
@@ -1067,6 +1103,7 @@ pub struct Security {
     /// * Security
     #[serde(
         rename = "NSUserTrackingUsageDescription",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub user_tracking_usage_description: Option<String>,
@@ -1089,6 +1126,7 @@ pub struct Security {
     /// * Security
     #[serde(
         rename = "NSAppleEventsUsageDescription",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub apple_events_usage_description: Option<String>,
@@ -1109,6 +1147,7 @@ pub struct Security {
     /// * Security
     #[serde(
         rename = "NSSystemAdministrationUsageDescription",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub system_administration_usage_description: Option<String>,
@@ -1138,6 +1177,7 @@ pub struct Security {
     /// * Security
     #[serde(
         rename = "ITSAppUsesNonExemptEncryption",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub app_uses_non_exempt_encryption: Option<bool>,
@@ -1157,6 +1197,7 @@ pub struct Security {
     /// * Security
     #[serde(
         rename = "ITSEncryptionExportComplianceCode",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub encryption_export_compliance_code: Option<String>,
@@ -1172,6 +1213,7 @@ pub struct Sensors {
     /// * SensorKit
     #[serde(
         rename = "NSSensorKitUsageDescription",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub sensor_kit_usage_description: Option<String>,
@@ -1182,6 +1224,7 @@ pub struct Sensors {
     /// * SensorKit
     #[serde(
         rename = "NSSensorKitUsageDetail",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub sensor_kit_usage_detail: Option<DefaultDictionary>,
@@ -1192,6 +1235,7 @@ pub struct Sensors {
     /// * SensorKit
     #[serde(
         rename = "NSSensorKitPrivacyPolicyURL",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub sensor_kit_privacy_policy_url: Option<String>,
@@ -1214,6 +1258,7 @@ pub struct Siri {
     /// * Intents
     #[serde(
         rename = "NSSiriUsageDescription",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub siri_usage_description: Option<String>,
@@ -1239,6 +1284,7 @@ pub struct Speech {
     /// * Speech
     #[serde(
         rename = "NSSpeechRecognitionUsageDescription",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub speech_recognition_usage_description: Option<String>,
@@ -1261,6 +1307,7 @@ pub struct TvResource {
     /// * TVUIKit
     #[serde(
         rename = "NSVideoSubscriberAccountUsageDescription",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub video_subscriber_account_usage_description: Option<String>,
@@ -1278,6 +1325,7 @@ pub struct WiFi {
     /// * UIKit
     #[serde(
         rename = "UIRequiresPersistentWiFi",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub requires_persistent_wifi: Option<bool>,
